# == Class: postfix
#
# Installs Postfix as a client or a server and configures it to use a smart
# host for outgoing email.
#
# === Parameters
#
# [*smarthost*]
#   (Required) The hostname of the smart host.
#
# [*port*]
#   (Optional) The port to connect to on the smart host (defaults to none).
#
# [*username*]
#   (Required) The username to login to the smart host.
#
# [*password*]
#   (Required) The password to login to the smart host.
#
# [*admin_email*]
#   The email address server generated emails should be sent to (this is
#   added as an alias for root@host).
#
# [*alias_domains*]
#   (Optional) Array of domains the node is responsible for. When set this
#   also configures postfix to run as a server listening for connections
#   on all interfaces (defaults to false).
#
# [*alias_files*]
#   (Optional) An array of additional alias files for Postfix to include
#   in its alias database.
#
# [*key_file*]
#   Key to use for TLS (defaults to /etc/ssl/private/ssl-cert-snakeoil.key)
#   
# [*cert_file*]
#   Cert to use for TLS (defaults to /etc/ssl/certs/ssl-cert-snakeoil.key)
#
# [*ca_file*]
#   CA file to use for TLS (defaults to /etc/ssl/certs/ca-certificates.crt)
#   
# [*sasl_packages*]
#   List of packages required to support SASL, set in params.pp.
#   
# === Authors
#
# David McNicol <david@mcnicks.org>
#

class postfix (
  $smarthost,
  $port = false,
  $username,
  $password,
  $admin_email,
  $alias_domains = false,
  $alias_files = [],
  $key_file = '/etc/ssl/private/ssl-cert-snakeoil.key',
  $cert_file = '/etc/ssl/certs/ssl-cert-snakeoil.pem',
  $ca_file = '/etc/ssl/certs/ca-certificates.crt',
  $sasl_packages = $postfix::params::sasl_packages,
) inherits postfix::params {

  if $sasl_packages {

    package { $sasl_packages:
      ensure => 'installed',
      before => Class['postfix::install']
    }

  }

  class { 'postfix::install':
    smarthost     => $smarthost,
    port          => $port,
    username      => $username,
    password      => $password,
    admin_email   => $admin_email,
    alias_domains => $alias_domains,
    alias_files   => $alias_files,
    key_file      => $key_file,
    cert_file     => $cert_file,
    ca_file       => $ca_file
  }

  contain 'postfix::install'

  class { 'postfix::config':
    admin_email => $admin_email,
    alias_files => $alias_files
  }

  contain 'postfix::config'
}
